# Encoders
A library of neural encoders developed by Soco Inc


## Make a package
    python setup.py bdist_wheel
    twine upload dist/*

## Usage
    
    python exmaple.py
    
### Available models
#### English
- bert-base-nli-mean-tokens
- bert-base-nli-stsb-mean-tokens
- bert-base-wikipedia-sections-mean-tokens
- bert-large-nli-mean-tokens
- bert-large-nli-stsb-mean-tokens
- en-RnnEncoder-1563406351
- en-RnnEncoder-1563826953

#### Chinese
- bert-base-zh-mean-tokens